@@ -9,4 +9,4 @@ val convert_constr_to_cw_pair :
   Constrexpr.constr_expr_r CAst.t -> GenericLib.constructor * weight_ast
 val register_weights_object :
   (GenericLib.constructor * weight_ast) list -> Libobject.obj
-val lookup_weight : CtrMap.key -> GenericLib.var -> GenericLib.coq_expr
+val lookup_weight : bool -> CtrMap.key -> GenericLib.var -> GenericLib.coq_expr
